import {reactive} from "vue";
import {io} from "socket.io-client";
import Cookies from "js-cookie";

export const state = reactive({
    connected: false,
    user: undefined,
    room: undefined
});

// TODO: Вместо undefined загружать ссылку из конфига
const URL = process.env.NODE_ENV === "production" ? undefined : "http://127.0.0.1:8000";

export const socket_connection = (username, {password = undefined, token = undefined} = {}) =>{
    const socket = io(URL, {
        path: "/ws/game/",
        auth: {
            username: username,
            password: password,
            token: token
        }
    });

    socket.on("userInfo", (data)=>{
        state.user = data
        Cookies.set("token", data.token)
        Cookies.set("username", data.username)
        if (data.in_room && state.room?.room_id !== data.in_room){
            socket.emit("joinRoom", state.user.username, state.user.token, data.in_room, data.room_password)
        }
    });

    socket.on("roomInfo", (data) =>{
        state.room = data
    })

    socket.on("connect", () => {
        state.connected = true;
    });

    socket.on("disconnect", () => {
        state.connected = false;
        state.user = undefined;
        state.room = undefined;
    });

    socket.on("roomCreated", (data) => {
        socket.emit("joinRoom", state.user.username, state.user.token, data.room_id, data.room_password)
    });

    return socket;
}
